# Workflow Picker
# 2014-05-13 by Derick Fay
#
# built with Dean Jackson's Workflow Library
# http://www.deanishe.net/alfred-workflow/index.html
#
# partly based on Shawn Patrick Rice's help workflow
# https://github.com/shawnrice/alfred2-workflow-help/blob/master/help.py
#
# 2014-05-13: initial version
# 2014-05-15: updated to check for prefs file and to make sure 'categories' key is in prefs file
# 2014-05-22: updated to use query to limit results

import sys
import os
import subprocess
from workflow import Workflow
from plistlib import *

def main(wf):
	if len(wf.args):
		query = wf.args[0]
	else:
		query = ''

	# convert prefs file from binary to XML then read it
	tempDir = os.path.expanduser("~/Library/Application Support/Alfred 2/Workflow Data/fm.fastmail.dfay.workflowpicker")	
	if not os.path.isdir(tempDir):
		os.makedirs(tempDir)
	tempFile = tempDir+"/Alfred-Preferences.plist"
	catsExist = False # assume the user hasn't created categories
	
	prefFile=os.path.expanduser("~/Library/Preferences/com.runningwithcrayons.Alfred-Preferences.plist")
		
	subprocess.call(["plutil","-convert", "xml1", prefFile, "-o", tempFile])
	prefs = readPlist(tempFile)

	# get the workflow directory from Alfred preferences
	
	if 'syncfolder' in prefs:
		thePath = prefs['syncfolder']+'/Alfred.alfredpreferences/preferences/workflows/'
		workflowPath = os.path.expanduser(thePath)
	else:
		workflowPath = os.path.expanduser('~/Library/Application Support/Alfred 2/Alfred.alfredpreferences/workflows/')
	
	# check to make sure prefs file with categories exists
	if os.path.isfile(workflowPath+'prefs.plist'):
		catsExist = True
	
	if catsExist:
		pl = readPlist(workflowPath+'prefs.plist')
		if 'categories' not in pl:
			catsExist = False

	# build the results
	if query == '':
		results = ['All']
	else:
		results = []
	if catsExist:	
		for i in pl['categories']:
			if (query.lower() in i.lower()):
				results = results+[i]
	results = sorted (results)
	for i in results:
		wf.add_item(title=i,
				valid=True,
				arg=i,
				icon="folder.png")

#	wf.add_item(title='Uncategorised',
#				valid=True,
#				arg='Uncategorised')
# never got this to work
		
	wf.send_feedback()

if __name__ == u"__main__":
	wf = Workflow()
	sys.exit(wf.run(main))