# Hotkey List
# 2014-05-20 by Derick Fay
# 2014-05-22: updated to filter based on query 
#
# built with Dean Jackson's Workflow Library
# http://www.deanishe.net/alfred-workflow/index.html
#
# partly based on Shawn Patrick Rice's help workflow
# https://github.com/shawnrice/alfred2-workflow-help/blob/master/help.py
#


import sys
import os
from workflow import Workflow
from plistlib import *

shift = u"\u21E7"
control = u"\u2303"
command = u"\u2318"
option = u"\u2325"

hotmod = {		131072 : shift,
				262144 : control,
				262401 : control,
				393216 : shift+control,
				524288 : option,
				655360 : shift+option,
				786432 : control+option,
				917504 : shift+control+option,
				1048576 : command,
				1179648 : shift+command,
				1310720 : control+command,
				1310985 : control+command,
				1441792 : shift+control+command,
				1572864 : option+command,
				1703936 : shift+option+command,
				1835008 : control+option+command,
				1966080 : shift+control+option+command
}

hotarg = {		0 : "No Argument",
				1 : "Selection in OS X",
				2 : "OS X Clipboard Contents",
				3 : "Text"
}

hotaction = { 	0 : "Pass through to Workflow",
				1 : "Show Alfred"
}


def main(wf):
# Get query from Alfred
	if len(wf.args):
		query = wf.args[0]
	else:
		query = ''

	# Get list of locations of workflow plists
	listdir = os.path.dirname(os.getcwd())
	dirs = os.walk(listdir).next()[1]

	results = []

	for folder in dirs:
		try:
			plistFile = listdir + "/" + folder + "/info.plist" # find the plist file
			try:
				iconFile = listdir + "/" + folder + "/icon.png"
			except:
				'icon missing'
			pl = readPlist(plistFile)
			source=pl['name']
			if "objects" in pl:
				for item in pl['objects']:
					if item['type'] == "alfred.workflow.trigger.hotkey":
						hotkey = ""
						takesArg = ""
						if "hotmod" in item['config'] and item['config']['hotmod']:
							if item['config']['hotmod'] in hotmod:
								hotkey = item['config']['hotstring'] + " " +hotmod[item['config']['hotmod']] 
							else:
								hotkey = "Error reading hotkey: try re-entering the hotkey in Alfred's preferences"
						else:
							hotkey = "(Not yet defined)" 
						# print "hotkey found: "+hotkey
						if item['config']['argument']:
							try:
								takesArg = item['config']['argumenttext']
							except:
								takesArg = hotarg[item['config']['argument']]
						if (query.lower() in hotkey) or (query.upper() in hotkey):								
							results=results+[{'title':hotkey,'subtitle':takesArg,'valid':True,'icon':iconFile,'source':source}]	
		except:
			'plist file missing'

	# put defined hotkeys at the start & sort by key
	start = []
	end = []
	start=filter(lambda x:x['title']!= "(Not yet defined)", results)
	start = sorted (start, key = lambda item:item['title'])

	# put undefined hotkeys at the end and group by workflow
	end=filter(lambda x:x['title']== "(Not yet defined)", results)
	end = sorted (end, key = lambda item:item['source'])
	results = start+end
	
	for r in results:
		wf.add_item(title=r['title'],
						subtitle=r['source']+": "+r['subtitle'],
						valid=r['valid'],
						icon=r['icon'])
	wf.send_feedback()
if __name__ == u"__main__":
	wf = Workflow()
	sys.exit(wf.run(main))
